from typing import Tuple, Optional
from PIL import Image
from PIL.ImageSequence import Iterator as SeqIterator
import glob
import os

def create_animated_png(
    image: Image, size: tuple, do_watermark: bool = True
) -> Tuple[Image.Image, dict]:
    'If the image is a PNG/APNG, create an its thumbnail here.'
    save_kwargs = dict()
    frame_durations = list()
    frame_disposals = list()
    frame_blends = list()

    def _thumbnails(index_size: Optional[Tuple[int, int]] = None) -> Image:
        'Inner iterator for frames.'
        for idx, frame in enumerate(frames):  # type: int, Image
            if index_size and frame.size != index_size:
                continue
            thumbnail_rgba = frame.copy() if frame.mode == 'RGBA' \
                else frame.convert(mode='RGBA')  # type: Image
            if size != frame.size:
                thumbnail_rgba.thumbnail(size=size, reducing_gap=3.0)
            frame_durations.append(frame.info.get('duration', 1000))
            frame_disposals.append(frame.info.get('disposal', 0))
            frame_blends.append(frame.info.get('blend', 0))
            yield thumbnail_rgba

    frames = SeqIterator(im=image)
    output_image = next(_thumbnails())
    append_images = list(_thumbnails(index_size=output_image.size))
    save_kwargs.update(
        format='PNG', optimize=True, save_all=True,
        append_images=append_images, loop=output_image.info.get('loop', 0),
        duration=frame_durations, blend=frame_blends)
    return output_image, save_kwargs

for file in glob.glob("**/*.webp", recursive=True):
     i = Image.open(file)
     i.load()
     i2, save_kwargs = create_animated_png(i, i.size, True)
     i2.save(file.replace("webp", "apng"), **save_kwargs)
     i.close()
     #os.remove(file)
